@@ -9,8 +9,8 @@ from myst.models.timing import AbsoluteTiming, CronTiming, RelativeTiming
 from myst.resources import hpo
 from myst.resources.backtest import Backtest, BacktestJob
 from myst.resources.hpo import HPO
-from myst.resources.input import Input
-from myst.resources.layer import Layer
+from myst.resources.input import ModelInput, OperationInput
+from myst.resources.layer import TimeSeriesLayer
 from myst.resources.model import Model
 from myst.resources.operation import Operation
 from myst.resources.policy import ModelFitPolicy, Policy, TimeSeriesRunPolicy
@@ -33,8 +33,9 @@ __all__ = [
     "Backtest",
     "HPO",
     "CronTiming",
-    "Input",
-    "Layer",
+    "ModelInput",
+    "OperationInput",
+    "TimeSeriesLayer",
     "Model",
     "ModelFitPolicy",
     "Operation",
