@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.organization_list import OrganizationList
+from myst.openapi.models.organization_list import OrganizationList
 
 
 def request_sync(client: Client) -> OrganizationList:
