@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.project_list import ProjectList
+from myst.openapi.models.project_list import ProjectList
 
 
 def request_sync(client: Client) -> ProjectList:
