@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -7,6 +9,6 @@ from myst.models import base_model
 class AbsoluteTimingCreate(base_model.BaseModel):
     """Absolute timing schema for create requests."""
 
-    object_: Literal["Timing"] = Field(..., alias="object")
     type: Literal["AbsoluteTiming"]
     time: str
+    object_: Optional[Literal["Timing"]] = Field("Timing", alias="object")
