@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -9,6 +7,6 @@ from myst.models import base_model
 class AbsoluteTimingGet(base_model.BaseModel):
     """Absolute timing schema for get responses."""
 
+    object_: Literal["Timing"] = Field(..., alias="object")
+    type: Literal["AbsoluteTiming"]
     time: str
-    object_: Optional[Literal["Timing"]] = Field("Timing", alias="object")
-    type: Optional[Literal["AbsoluteTiming"]] = "AbsoluteTiming"
