@@ -14,8 +14,10 @@ class HPOJobGet(base_model.BaseModel):
     uuid: str
     create_time: str
     hpo: str
+    creator: str
     schedule_time: str
+    state: HPOJobState
     num_trials_completed: int
     update_time: Optional[str] = None
-    state: Optional[HPOJobState] = HPOJobState.PENDING
+    detail: Optional[str] = None
     result: Optional[str] = None
