@@ -1,12 +1,11 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.model_fit_result_get import ModelFitResultGet
+from myst.openapi.models.model_fit_result_list_item import ModelFitResultListItem
 
 
 class ModelFitResultList(base_model.BaseModel):
     """Schema for model fit result list responses."""
 
-    data: List[ModelFitResultGet]
+    data: List[ModelFitResultListItem]
     has_more: bool
