@@ -4,7 +4,7 @@ from myst.models import base_model
 
 
 class SourceUpdateParameters(base_model.BaseModel):
-    """The parameters used in the source's connector. Must adhere to connector's parameter schema."""
+    """The parameters used in the node's connector. Must adhere to connector's parameter schema."""
 
     __root__: Dict[str, Any]
 
