@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.user_get import UserGet
+from myst.openapi.models.user_get import UserGet
 
 
 class UserList(base_model.BaseModel):
